%undefine _debugsource_packages
%define _build_id_links none

%bcond_with openblas

%if %{with openblas}
%global destdir /usr/local/scalapack/openblas/%{version}
%global modulefile_path /usr/local/share/Modules/modulefiles/scalapack/openblas
%else
%global destdir /usr/local/scalapack/%{version}
%global modulefile_path /usr/local/share/Modules/modulefiles/scalapack
%endif

%ifarch s390 s390x
  # No OpenMPI support on these arches
  %bcond_with openmpi
%else
  %bcond_without openmpi
%endif

# intel mpi
%bcond_without impi

# mpich
%bcond_with mpich

%{!?openmpiversion: %global openmpiversion 4.1.0}
%global openmpinumversion %( printf "%02d%02d%02d" `echo %{openmpiversion} | cut -d. -f1,2,3 --output-delimiter=" "` )
%global openmpimodule openmpi-%{openmpiversion}
%{!?intelmpiversion: %global intelmpiversion 2021.1.1}
%global intelmpinumversion %( echo %{intelmpiversion} | tr -d . )

Summary: A subset of LAPACK routines redesigned for heterogeneous computing
%global rname scalapack
Version: 2.0.2
%global scalapacknumversion %( printf "%02d%02d%02d" `echo %{version} | cut -d. -f1,2,3 --output-delimiter=" "` )
%if %{with openblas}
Name: scalapack%{scalapacknumversion}-openblas
%else
Name: scalapack%{scalapacknumversion}
%endif
Release: 18%{?dist}
# This is freely distributable without any restrictions.
License: Public Domain
Group: Development/Libraries
URL: http://www.netlib.org/scalapack/
Source0: http://www.netlib.org/scalapack/scalapack-%{version}.tgz
%if %{with openblas}
BuildRequires: openblas-devel
%else
BuildRequires: lapack-devel, blas-devel
%endif
BuildRequires: gcc-gfortran, glibc-devel
%if %{with mpich}
BuildRequires: mpich-devel-static
BuildRequires: environment-modules
%endif
%if %{with openmpi}
BuildRequires: openmpi%{openmpinumversion}-gcc-devel
BuildRequires: environment-modules
%endif
%if %{with impi}
BuildRequires: intel-mpi%{intelmpinumversion}-modules-gcc
BuildRequires: intel-mpi%{intelmpinumversion}-modules-devel
BuildRequires: environment-modules
%endif
# Build shared-library for ScaLAPACK
Patch0: scalapack-2.0.2-fedora.patch
# Build shared library for BLACS
Patch1: scalapack-2.0.2-shared-blacs.patch
# Add missing functions
Patch2: scalapack-2.0.2-missing-functions.patch

%description
The ScaLAPACK (or Scalable LAPACK) library includes a subset 
of LAPACK routines redesigned for distributed memory MIMD 
parallel computers. It is currently written in a 
Single-Program-Multiple-Data style using explicit message 
passing for inter-processor communication. It assumes 
matrices are laid out in a two-dimensional block cyclic 
decomposition.

ScaLAPACK is designed for heterogeneous computing and is 
portable on any computer that supports MPI or PVM.

Like LAPACK, the ScaLAPACK routines are based on 
block-partitioned algorithms in order to minimize the frequency 
of data movement between different levels of the memory hierarchy. 
(For such machines, the memory hierarchy includes the off-processor 
memory of other processors, in addition to the hierarchy of registers, 
cache, and local memory on each processor.) The fundamental building 
blocks of the ScaLAPACK library are distributed memory versions (PBLAS) 
of the Level 1, 2 and 3 BLAS, and a set of Basic Linear Algebra 
Communication Subprograms (BLACS) for communication tasks that arise 
frequently in parallel linear algebra computations. In the ScaLAPACK 
routines, all inter-processor communication occurs within the PBLAS and the 
BLACS. One of the design goals of ScaLAPACK was to have the ScaLAPACK 
routines resemble their LAPACK equivalents as much as possible. 

%package common
Summary: Common files for scalapack
Group: Development/Libraries

%description common
The ScaLAPACK (or Scalable LAPACK) library includes a subset 
of LAPACK routines redesigned for distributed memory MIMD 
parallel computers. It is currently written in a 
Single-Program-Multiple-Data style using explicit message 
passing for inter-processor communication. It assumes 
matrices are laid out in a two-dimensional block cyclic 
decomposition.

ScaLAPACK is designed for heterogeneous computing and is 
portable on any computer that supports MPI or PVM.

Like LAPACK, the ScaLAPACK routines are based on 
block-partitioned algorithms in order to minimize the frequency 
of data movement between different levels of the memory hierarchy. 
(For such machines, the memory hierarchy includes the off-processor 
memory of other processors, in addition to the hierarchy of registers, 
cache, and local memory on each processor.) The fundamental building 
blocks of the ScaLAPACK library are distributed memory versions (PBLAS) 
of the Level 1, 2 and 3 BLAS, and a set of Basic Linear Algebra 
Communication Subprograms (BLACS) for communication tasks that arise 
frequently in parallel linear algebra computations. In the ScaLAPACK 
routines, all inter-processor communication occurs within the PBLAS and the 
BLACS. One of the design goals of ScaLAPACK was to have the ScaLAPACK 
routines resemble their LAPACK equivalents as much as possible. 

This file contains common files which are not specific to any MPI implementation.

%if %{with mpich}
%package mpich
Summary: BLACS and ScaLAPACK libraries compiled against mpich
Group: Development/Libraries
Requires: %{name}-common = %{version}-%{release}
#Obsoletes: blacs-mpich2 < 1.1-50
Requires: mpich

%description mpich
The ScaLAPACK (or Scalable LAPACK) library includes a subset
of LAPACK routines redesigned for distributed memory MIMD
parallel computers. It is currently written in a
Single-Program-Multiple-Data style using explicit message
passing for inter-processor communication. It assumes
matrices are laid out in a two-dimensional block cyclic
decomposition.

ScaLAPACK is designed for heterogeneous computing and is
portable on any computer that supports MPI or PVM.

Like LAPACK, the ScaLAPACK routines are based on
block-partitioned algorithms in order to minimize the frequency
of data movement between different levels of the memory hierarchy.
(For such machines, the memory hierarchy includes the off-processor
memory of other processors, in addition to the hierarchy of registers,
cache, and local memory on each processor.) The fundamental building
blocks of the ScaLAPACK library are distributed memory versions (PBLAS)
of the Level 1, 2 and 3 BLAS, and a set of Basic Linear Algebra
Communication Subprograms (BLACS) for communication tasks that arise
frequently in parallel linear algebra computations. In the ScaLAPACK
routines, all inter-processor communication occurs within the PBLAS and the
BLACS. One of the design goals of ScaLAPACK was to have the ScaLAPACK
routines resemble their LAPACK equivalents as much as possible.

This package contains ScaLAPACK and BLACS libraries compiled with mpich.

%package mpich-devel
Summary: Development libraries for ScaLAPACK and BLACS (mpich)
Group: Development/Libraries
Requires: %{name}-mpich = %{version}-%{release}
Requires: mpich-devel
Provides: %{name}-mpich2-devel = %{version}-%{release}

%description mpich-devel
This package contains development libraries for ScaLAPACK and BLACS, compiled against mpich.

%package mpich-static
Summary: Static libraries for ScaLAPACK and BLACS (mpich)
Group: Development/Libraries
Requires: %{name}-mpich-devel = %{version}-%{release}
Provides: %{name}-mpich2-static = %{version}-%{release}

%description mpich-static
This package contains static libraries for ScaLAPACK and BLACS, compiled against mpich.
%endif

%if %{with openmpi}
%package openmpi%{openmpinumversion}
Summary: ScaLAPACK and BLACS libraries compiled against openmpi %{openmpiversion}
Group: Development/Libraries
Requires: %{name}-common = %{version}-%{release}
Requires: openmpi%{openmpinumversion}-gcc-runtime

%description openmpi%{openmpinumversion}
The ScaLAPACK (or Scalable LAPACK) library includes a subset
of LAPACK routines redesigned for distributed memory MIMD
parallel computers. It is currently written in a
Single-Program-Multiple-Data style using explicit message
passing for inter-processor communication. It assumes
matrices are laid out in a two-dimensional block cyclic
decomposition.

ScaLAPACK is designed for heterogeneous computing and is
portable on any computer that supports MPI or PVM.

Like LAPACK, the ScaLAPACK routines are based on
block-partitioned algorithms in order to minimize the frequency
of data movement between different levels of the memory hierarchy.
(For such machines, the memory hierarchy includes the off-processor
memory of other processors, in addition to the hierarchy of registers,
cache, and local memory on each processor.) The fundamental building
blocks of the ScaLAPACK library are distributed memory versions (PBLAS)
of the Level 1, 2 and 3 BLAS, and a set of Basic Linear Algebra
Communication Subprograms (BLACS) for communication tasks that arise
frequently in parallel linear algebra computations. In the ScaLAPACK
routines, all inter-processor communication occurs within the PBLAS and the
BLACS. One of the design goals of ScaLAPACK was to have the ScaLAPACK
routines resemble their LAPACK equivalents as much as possible.

This package contains ScaLAPACK and BLACS libraries compiled with openmpi.

%package openmpi%{openmpinumversion}-devel
Summary: Development libraries for ScaLAPACK and BLACS (openmpi)
Group: Development/Libraries
Requires: %{name}-openmpi%{openmpinumversion} = %{version}-%{release}
Requires: openmpi%{openmpinumversion}-gcc-devel

%description openmpi%{openmpinumversion}-devel
This package contains development libraries for ScaLAPACK and BLACS, compiled against openmpi.

%package openmpi%{openmpinumversion}-static
Summary: Static libraries for ScaLAPACK and BLACS (openmpi)
Group: Development/Libraries
Requires: %{name}-openmpi%{openmpinumversion}-devel = %{version}-%{release}

%description openmpi%{openmpinumversion}-static
This package contains static libraries for ScaLAPACK and BLACS, compiled against openmpi.
%endif

%if %{with impi}
%package impi
Summary: ScaLAPACK and BLACS libraries compiled against impi
Group: Development/Libraries
Requires: %{name}-common = %{version}-%{release}
Requires: intel-mpi-modules-gcc

%description impi
The ScaLAPACK (or Scalable LAPACK) library includes a subset
of LAPACK routines redesigned for distributed memory MIMD
parallel computers. It is currently written in a
Single-Program-Multiple-Data style using explicit message
passing for inter-processor communication. It assumes
matrices are laid out in a two-dimensional block cyclic
decomposition.

ScaLAPACK is designed for heterogeneous computing and is
portable on any computer that supports MPI or PVM.

Like LAPACK, the ScaLAPACK routines are based on
block-partitioned algorithms in order to minimize the frequency
of data movement between different levels of the memory hierarchy.
(For such machines, the memory hierarchy includes the off-processor
memory of other processors, in addition to the hierarchy of registers,
cache, and local memory on each processor.) The fundamental building
blocks of the ScaLAPACK library are distributed memory versions (PBLAS)
of the Level 1, 2 and 3 BLAS, and a set of Basic Linear Algebra
Communication Subprograms (BLACS) for communication tasks that arise
frequently in parallel linear algebra computations. In the ScaLAPACK
routines, all inter-processor communication occurs within the PBLAS and the
BLACS. One of the design goals of ScaLAPACK was to have the ScaLAPACK
routines resemble their LAPACK equivalents as much as possible.

This package contains ScaLAPACK and BLACS libraries compiled with intel mpi.

%package impi-devel
Summary: Development libraries for ScaLAPACK and BLACS (intel mpi)
Group: Development/Libraries
Requires: %{name}-impi = %{version}-%{release}
Requires: intel-mpi-modules-devel

%description impi-devel
This package contains development libraries for ScaLAPACK and BLACS, compiled against intel mpi.

%package impi-static
Summary: Static libraries for ScaLAPACK and BLACS (intel mpi)
Group: Development/Libraries
Requires: %{name}-impi-devel = %{version}-%{release}

%description impi-static
This package contains static libraries for ScaLAPACK and BLACS, compiled against intel mpi.
%endif

%prep
%setup -q -c -n %{rname}-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%if %{with openblas}
sed -i -e 's|^LIBS .*|LIBS = -lopenblas|' %{rname}-%{version}/SLmake.inc
sed -i -e 's|-lblas -llapack|-lopenblas|' %{rname}-%{version}/Makefile
%endif
for i in %{?with_mpich:mpich} %{?with_openmpi:%{openmpimodule}} %{?with_impi:intel-mpi}; do
  cp -a %{rname}-%{version} %{name}-%{version}-$i
done

%build
%global dobuild() \
cd %{name}-%{version}-$MPI_COMPILER_NAME ; \
make lib RPM_OPT_FLAGS=-O3; \
cd ..

%if %{with mpich}
# Build mpich version
export MPI_COMPILER_NAME=mpich
%{_mpich_load}
RPM_OPT_FLAGS=`echo $CFLAGS`
%dobuild
%{_mpich_unload}
%endif

%if %{with openmpi}
# Build OpenMPI version
export MPI_COMPILER_NAME=%{openmpimodule}
#{_openmpi_load}
module load openmpi
RPM_OPT_FLAGS=`echo $CFLAGS`
%dobuild
#%{_openmpi_unload}
module purge
%endif

%if %{with impi}
# Build OpenMPI version
export MPI_COMPILER_NAME=intel-mpi
module load intel-mpi
RPM_OPT_FLAGS=`echo $CFLAGS`
%dobuild
module purge
%endif

%install
mkdir -p ${RPM_BUILD_ROOT}%{destdir}

for i in %{?with_mpich:mpich} %{?with_openmpi:%{openmpimodule}} %{?with_impi:intel-mpi}; do
  mkdir -p %{buildroot}%{destdir}/$i/lib/
  pushd %{name}-%{version}-$i
  for f in *.a *.so*; do
    cp -f $f %{buildroot}%{destdir}/$i/lib/$f
  done
  popd
  mkdir -p %{buildroot}%{destdir}/$i/include
  # This file is independent of the MPI compiler used, but it is poorly named
  # So we'll put it in %{_includedir}/blacs/
  mkdir -p %{buildroot}%{destdir}/$i/include/blacs/
  install -p %{name}-%{version}-$i/BLACS/SRC/Bdef.h %{buildroot}%{destdir}/$i/include/blacs/

  pushd %{buildroot}%{destdir}/$i/lib/
  ln -fs libscalapack.so.2.0.0 libscalapack.so.2
  ln -s libscalapack.so.2.0.0 libscalapack.so
  ln -fs libmpiblacs.so.2.0.0 libmpiblacs.so.2
  ln -fs libmpiblacs.so.2.0.0 libmpiblacs.so
  cd ..
  ln -s lib lib64
  # ln -fs libmpiblacs.so.2.0.0 libmpiblacs.so.2
  # ln -s libmpiblacs.so.2.0.0 libmpiblacs.so
  popd

  case $i in
    openmpi*)
      PREREQ=openmpi
      ;;
    *)
      PREREQ=$i
      ;;
  esac

  mkdir -p %{buildroot}%{modulefile_path}/$i
  cat > %{buildroot}%{modulefile_path}/$i/%{version} <<ENDMODULE
#%Module

# NOTE: This is an automatically-generated file!  (generated by the
# %{name} RPM).  Any changes made here will be lost a) if the RPM is
# uninstalled, or b) if the RPM is upgraded or uninstalled.

proc ModulesHelp { } {
   puts stderr "This module adds scalapack %{version} compiled%{?with_openblas: with openblas} for $i to relevant paths"
}
setenv SCALAPACK_DIR %{destdir}/$i
prepend-path CPATH "%{destdir}/$i/include"
prepend-path LD_LIBRARY_PATH "%{destdir}/$i/lib"
prepend-path LIBRARY_PATH "%{destdir}/$i/lib"
prereq $PREREQ
ENDMODULE
done

# Copy docs
cd %{rname}-%{version}
cp -f README ../

%files common
%doc README
#{_includedir}/blacs/

%if %{with mpich}
%files mpich
%dir %{modulefile_path}
%dir %{modulefile_path}/mpich
%{modulefile_path}/mpich/%{version}
%{destdir}/mpich/lib/lib*.so.*
%{destdir}/mpich/lib64

%files mpich-devel
%{destdir}/mpich/include
%{destdir}/mpich/lib/lib*.so

%files mpich-static
%{destdir}/mpich/lib/lib*.a
%endif

%if %{with openmpi}
%files openmpi%{openmpinumversion}
%dir %{modulefile_path}
%dir %{modulefile_path}/%{openmpimodule}
%{modulefile_path}/%{openmpimodule}/%{version}
%{destdir}/%{openmpimodule}/lib/lib*.so.*
%{destdir}/%{openmpimodule}/lib64

%files openmpi%{openmpinumversion}-devel
%{destdir}/%{openmpimodule}/include
%{destdir}/%{openmpimodule}/lib/lib*.so

%files openmpi%{openmpinumversion}-static
%{destdir}/%{openmpimodule}/lib/lib*.a
%endif

%if %{with impi}
%files impi
%dir %{modulefile_path}
%dir %{modulefile_path}/intel-mpi
%{modulefile_path}/intel-mpi/%{version}
%{destdir}/intel-mpi/lib/lib*.so.*
%{destdir}/intel-mpi/lib64

%files impi-devel
%{destdir}/intel-mpi/include
%{destdir}/intel-mpi/lib/lib*.so

%files impi-static
%{destdir}/intel-mpi/lib/lib*.a
%endif

%changelog
* Thu Jul 28 2016 Tom Callaway <spot@fedoraproject.org> - 2.0.2-15
- fix scalapack shared library to properly have blacs inside it
- add explicit openmpi/mpich requires

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.2-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Jan 26 2016 Tom Callaway <spot@fedoraproject.org> - 2.0.2-13
- use global instead of define

* Tue Jan 19 2016 Orion Poplawski <orion@cora.nwra.com> - 2.0.2-12
- Make blacs-openmpi require blacs-common (bug #1299939)

* Mon Jan 18 2016 Tom Callaway <spot@fedoraproject.org> - 2.0.2-11.1
- inherit fixes from master branch into epel7
- rebuild against current libmpi in epel7

* Tue Sep 15 2015 Orion Poplawski <orion@cora.nwra.com> - 2.0.2-11
- Rebuild for openmpi 1.10.0

* Sat Aug 15 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 2.0.2-10
- Rebuild for MPI provides

* Sun Jul 26 2015 Sandro Mani <manisandro@gmail.com> - 2.0.2-9
- Rebuild for RPM MPI Requires Provides Change

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.2-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Mar 14 2015 Thomas Spura <tomspur@fedoraproject.org> - 2.0.2-7
- Rebuild for changed mpich libraries

* Thu Dec 18 2014 Tom Callaway <spot@fedoraproject.org> - 2.0.2-6
- add missing functions (thanks to d.love<at>liverpool.ac.uk)

* Thu Sep  4 2014 Thomas Spura <tomspur@fedoraproject.org> - 2.0.2-5
- rebuild for changed library inside openmpi (#1135728)

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Tue Jul  1 2014 Tom Callaway <spot@fedoraproject.org> - 2.0.2-3
- explictly link to other dependent libs

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat May 3 2014 Tom Callaway <spot@fedoraproject.org> - 2.0.2-1
- update to 2.0.2
- subpackage blacs

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.5-20
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sat Jul 20 2013 Deji Akingunola <dakingun@gmail.com> - 1.7.5-19
- Rename mpich2 sub-packages to mpich and rebuild for mpich-3.0

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.5-18
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Nov 15 2012 Tom Callaway <spot@fedoraproject.org> - 1.7.5-17
- rebuild for new mpich2

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.5-16
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.5-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Aug 03 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.7.5-14
- Bump spec.

* Wed Aug 03 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.7.5-13
- Honor MPI guidelines wrt placement of libraries.
- Drop unnecessary module file.
- A few rpmlint fixes.

* Tue Mar 29 2011 Deji Akingunola <dakingun@gmail.com> - 1.7.5-12
- Rebuild for mpich2 soname bump

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.5-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Oct 19 2010 Deji Akingunola <dakingun@gmail.com> - 1.7.5-11
- Rebuild for both mpich2 and openmpi updates

* Wed Jul  7 2010 Tom "spot" Callaway <tcallawa@redhat.com> - 1.7.5-10
- Move all BuildRequires to the top of the spec file
- -static packages now Require matching -devel package, they're not very useful otherwise

* Tue Dec 15 2009 Deji Akingunola <dakingun@gmail.com> - 1.7.5-9
- Buildrequire mpich2-devel-static

* Wed Dec  9 2009 Tom "spot" Callaway <tcallawa@redhat.com> - 1.7.5-8
- drop lam support (Provides/Obsoletes by mpich2, which is a hack, but something's gotta do it)
- move static libs to static subpackages (resolves bz 545150)

* Thu Aug  6 2009 Tom "spot" Callaway <tcallawa@redhat.com> - 1.7.5-7
- rework package to handle all supported MPI environments in Fedora

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.5-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7.5-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Sep 23 2008 Tom "spot" Callaway <tcallawa@redhat.com> 1.7.5-4
- incorporate Deji Akingunola's changes (bz 462424)
- build against openmpi instead of lam

* Tue Jul  8 2008 Tom "spot" Callaway <tcallawa@redhat.com> 1.7.5-3
- fix compile against new lam paths

* Wed Feb 13 2008 Tom "spot" Callaway <tcallawa@redhat.com> 1.7.5-2
- rebuild for new gcc

* Mon Aug 27 2007 Tom "spot" Callaway <tcallawa@redhat.com> 1.7.5-1.1
- rebuild for BuildID

* Thu Jan 18 2007 Tom "spot" Callaway <tcallawa@redhat.com> 1.7.5-1
- bump to 1.7.5

* Fri Sep 15 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.7.4-4
- I said "BR" not "R". Stupid packager.

* Fri Sep 15 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.7.4-3
- fix BR: lam-devel

* Fri Sep 15 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.7.4-2
- fix 64bit patch

* Fri Sep 15 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.7.4-1
- bump to 1.7.4

* Wed Mar  8 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-13
- lam moved into _libdir/lam... need to fix patches

* Wed Mar  8 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-12
- set -fPIC as NOOPT

* Sun Feb 26 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-11
- fix 64 bit builds
- enable shared libraries
- split package into base and devel

* Tue Feb 14 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-10
- Incorporate Andrew Gormanly's fixes

* Mon Jan  9 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-9
- fix BR

* Mon Dec 19 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-8
- rebuild for gcc4.1

* Sun May 15 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-7
- 64 bit library fix

* Mon May  9 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-6
- remove hardcoded dist tags

* Sun May  8 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-4
- fix broken patch for fc-3 branch

* Sun Apr 24 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-3
- use dist tag
- fix fc3 BuildRequires

* Tue Apr 19 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-2
- fix buildroot
- add gcc-gfortran to BuildRequires (gcc-g77 for fc3)

* Mon Apr 18 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.7-1
- initial package creation
